# Cornea

![GitHub](https://img.shields.io/github/license/pravinba9495/cornea)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/ea8ff99a54fb4f51990ae09014fd0978)](https://www.codacy.com/app/pravinba9495/cornea?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=pravinba9495/cornea&amp;utm_campaign=Badge_Grade)

A PyPI package to extract insightful information about an image using Machine Intelligence
